pub fn detect_format(header: &[u8]) -> AudioFormatExpand description
Detect audio format from the first bytes of a file (magic bytes).
pub fn detect_format(header: &[u8]) -> AudioFormatDetect audio format from the first bytes of a file (magic bytes).